/*--------------------------------------------------------------------------+
$Id$
|                                                                          |
| Copyright 2011 ForTISS GmbH                     |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.kernel.interfaces;

import java.util.List;

import org.eclipse.emf.ecore.EObject;
import org.eclipse.jface.resource.ImageDescriptor;
import org.eclipse.swt.graphics.Image;

/**
 * A model element handler provides information about a specific type of model
 * elements.
 * 
 * @author hoelzlf
 * @author $Author$
 * @version $Rev$
 * @ConQAT.Rating RED Hash: 35E448552D7EE98A2C2FD4CF18F03C05
 */
public interface IHandler<T extends EObject> {

	/** Returns the name of the model element (if any). */
	String getName(T element);

	/** Returns a description of the model element (if any). */
	String getDescription(T element);

	/** Returns the icon of the model element. */
	Image getIcon();

	/** Returns image descriptor to be used as icon image. */
	public ImageDescriptor getIconImageDescriptor();

	/** Returns all children acting as nodes. */
	List<EObject> getSubnodes(T element);

	/** Returns all children acting as connectors. */
	List<EObject> getConnectors(T element);

	/** Returns all connections entering this element. */
	List<EObject> getIncomingConnections(T element);

	/** Returns all connections leaving this element. */
	List<EObject> getOutgoingConnections(T element);

	/** Returns all children acting as a (visible) specification. */
	List<EObject> getSpecifications(T element);
}
